@@ -1,6 +1,7 @@
 ## File Name: add.lead.R
-## File Version: 0.04
+## File Version: 0.05
 
-add.lead <- function(x, width=max(nchar(x))){
+add.lead <- function(x, width=max(nchar(x)))
+{
     sprintf(paste('%0', width, 'i', sep=''), x)
 }
