@@ -1,14 +1,14 @@
 ## File Name: summary.tam.mml.3pl.R
-## File Version: 9.30
+## File Version: 9.37
 
-#*******************************************************
-# Summary for tam.mml.3pl object                 *
+# summary for tam.mml.3pl object
 summary.tam.mml.3pl <- function( object, file=NULL, ...)
 {
 
     tam_osink( file=file)
 
-    cat("------------------------------------------------------------\n")
+    sdisplay <- tam_summary_display()
+    cat(sdisplay)
 
     #- package and R session
     tam_print_package_rsession(pack="TAM")
@@ -20,8 +20,8 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
     cat("IRT Model", irtmodel, " (Function 'tam.mml.3pl')")
     tam_print_call(object$CALL)
 
-    cat("------------------------------------------------------------\n")
-    cat( "Number of iterations=", object$iter, "\n\n" )
+    cat(sdisplay)
+    cat( "Number of iterations", "=", object$iter, "\n\n" )
 
     ctr <- object$control
     cat("Skill space:", ifelse(object$skillspace=="normal",
@@ -40,26 +40,26 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
             }
         }
     }
-    cat( "\nDeviance=", round( object$deviance, 2 ), " | " )
-    cat( "Log Likelihood=", round( -object$deviance/2, 2 ), "\n" )
-    cat( "Number of persons=", object$nstud, "\n" )
-    cat( "Number of persons used=", object$ic$n, "\n" )
+    cat( "\nDeviance", "=", round( object$deviance, 2 ), " | " )
+    cat( "Log Likelihood", "=", round( -object$deviance/2, 2 ), "\n" )
+    cat( "Number of persons", "=", object$nstud, "\n" )
+    cat( "Number of persons used", "=", object$ic$n, "\n" )
 
     if( ! is.null( object$formulaA)  ){
-        cat( "Number of generalized items=", object$nitems, "\n" )
-        cat( "Number of items=", ncol(object$resp_orig), "\n" )
+        cat( "Number of generalized items", "=", object$nitems, "\n" )
+        cat( "Number of items", "=", ncol(object$resp_orig), "\n" )
     } else {
-        cat( "Number of items=", object$nitems, "\n" )
+        cat( "Number of items", "=", object$nitems, "\n" )
     }
 
-    cat( "Number of estimated parameters=", object$ic$Npars, "\n" )
-    cat( "    Item threshold parameters=", object$ic$Nparsxsi, "\n" )
-    cat( "    Item slope parameters  =", object$ic$NparsB, "\n" )
-    cat( "      Non-active item slopes=", object$ic$Ngamma.nonactive, "\n" )
-    cat( "    Item guessing parameters=", object$ic$Nguess, "\n" )
-    cat( "    Regression parameters  =", object$ic$Nparsbeta, "\n" )
-    cat( "    (Co)Variance parameters=", object$ic$Nparscov, "\n" )
-    cat( "    Delta parameters       =", object$ic$Ndelta, "\n\n" )
+    cat( "Number of estimated parameters", "=", object$ic$Npars, "\n" )
+    cat( "    Item threshold parameters", "=", object$ic$Nparsxsi, "\n" )
+    cat( "    Item slope parameters", "=", object$ic$NparsB, "\n" )
+    cat( "      Non-active item slopes", "=", object$ic$Ngamma.nonactive, "\n" )
+    cat( "    Item guessing parameters", "=", object$ic$Nguess, "\n" )
+    cat( "    Regression parameters", "=", object$ic$Nparsbeta, "\n" )
+    cat( "    Variance/covariance parameters", "=", object$ic$Nparscov, "\n" )
+    cat( "    Delta parameters    ", "=", object$ic$Ndelta, "\n\n" )
 
     #--- print information criteria
     res <- tam_summary_print_ic( object=object )
@@ -70,11 +70,11 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
     G <- object$G
 
     if (object$skillspace=="normal"){
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("EAP Reliability\n")
         obji <- round( object$EAP.rel, 3 )
         print( obji )
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("Covariances and Variances\n")
         if ( object$G >1){
             group_names <- paste0("Group", object$groups )
@@ -94,7 +94,7 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
         if (G==1){
             print( obji )
         }
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("Correlations and Standard Deviations (in the diagonal)\n")
         if ( object$G > 1){
             group_names <- paste0("Group", object$groups )
@@ -115,31 +115,31 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
 
         if (object$G==1){
             obji <- round( obji, 3 )
-            print( obji )
+            print(obji)
         }
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("Regression Coefficients\n")
         obji <- round( object$beta, 5 )
-        print( obji )
+        print(obji)
     }   # end distribution skillspace=="normal"
     #*******************************************************************
     if (object$skillspace !="normal"){
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("Trait distribution parameters delta\n")
         obji <- round( object$delta, 4 )
         colnames(obji) <- paste0("Group", 1:object$G)
-        print( obji )
+        print(obji)
         TP <- nrow(obji)
 
         if ( PK < 10 ){
-            cat("------------------------------------------------------------\n")
+            cat(sdisplay)
             cat("Full Trait distribution\n")
             obji <- round( object$pi.k, 4 )
             colnames(obji) <- paste0("Group", 1:object$G)
             if ( TP < 100 ){
                 print( obji )
             }
-            cat("------------------------------------------------------------\n")
+            cat(sdisplay)
             cat("Moments of Trait Distribution\n")
             obji <- object$pi.k
             cat( "\nM Trait:\n" )
@@ -157,7 +157,7 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
     }
 
     if (PK < 10 ){
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("Item Parameters -A*Xsi\n")
         obji <- object$item
         tam_round_data_frame_print(obji=obji, from=2, digits=3)
@@ -173,7 +173,7 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
             tam_round_data_frame_print(obji=obji, from=1, digits=3)
         }
     } else {  # PK >=10
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         if (( object$maxK > 2 ) | ( object$printxsi) ){
             cat("\nItem Parameters Xsi\n")
             obji <- object$xsi
@@ -190,8 +190,6 @@ summary.tam.mml.3pl <- function( object, file=NULL, ...)
     obji <- object$gammaslope
     tam_round_data_frame_print(obji=obji, from=1, digits=3)
 
-
     #******
     tam_csink(file=file)
 }
-#*******************************************************
