@@ -1,10 +1,10 @@
 ## File Name: tam.personfit.R
-## File Version: 0.06
+## File Version: 0.07
 
 tam.personfit <- function(tamobj)
 {
     #** WLE estimation in case of MML estimation
-    if ( class(tamobj) !="tam.jml" ){
+    if ( ! inherits(tamobj,"tam.jml") ){
         res <- tam.wle(tamobj, progress=FALSE)
         tamobj$theta <- res$theta
         tamobj$xsi <- tamobj$xsi$xsi
