@@ -1,16 +1,16 @@
 ## File Name: tam.wle.R
-## File Version: 9.16
+## File Version: 9.171
 
 tam.wle <- function( tamobj, ... )
 {
     CALL <- match.call()
-    if(class(tamobj)=="tam.mml"){
+    if(inherits(tamobj,"tam.mml")){
         res <- tam.mml.wle2( tamobj, ...)
     }
-    if(class(tamobj)=="tamaan"){
+    if(inherits(tamobj,"tamaan")){
         res <- tam.mml.wle2( tamobj, ...)
     }
-    if(class(tamobj)=="tam.jml"){
+    if(inherits(tamobj,"tam.jml")){
         res <- tam_jml_wle( tamobj, ...)
     }
     attr(res,"call") <- CALL
