@@ -1,13 +1,13 @@
 ## File Name: tam_interval_index.R
-## File Version: 0.01
+## File Version: 0.04
+
 
-		
 # 'interval_index' searches an index when a frequency is exceeded
 # -> used in plausible value imputation
-tam_interval_index <- function(matr, rn){ 
-	res <- interval_index_C( matr, rn )
-	res <- res + 1
-	return(res)
-}		
+tam_interval_index <- function(matr, rn){
+    res <- tam_rcpp_interval_index( MATR=matr, RN=rn )
+    res <- res + 1
+    return(res)
+}
 
 interval_index <- tam_interval_index
