@@ -1,5 +1,5 @@
 ## File Name: tam_mml_ic_criteria.R
-## File Version: 0.03
+## File Version: 0.06
 
 
 tam_mml_ic_criteria <- function(ic)
@@ -17,6 +17,10 @@ tam_mml_ic_criteria <- function(ic)
     ic$CAIC <- dev + ( log(ic$n) + 1 )*ic$np
     # corrected AIC
     ic$AICc <- ic$AIC + 2*ic$np * ( ic$np + 1 ) / ( ic$n - ic$np - 1 )
+    # Gilula-Haberman log penalty
+    if (!is.null(ic$ghp_obs)){
+        ic$GHP <- ic$AIC / (2*ic$ghp_obs)
+    }
     #--- OUTPUT
     return(ic)
 }
